==> marshallEngine-0.7.0.tar.gz: marshallEngine-0.7.0/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/marshallEngine/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.md') as f:
        return f.read()

install_requires = [
    'pyyaml',
    'marshallEngine',
    'fundamentals',
    'astrocalc',
    'hmpty',
    'astropy',
    'matplotlib',
    'panstamps',
    'transientNamer',
    'tornado',
    'numpy'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    c_exclude_list = ['healpy', 'astropy',
                      'numpy', 'sherlock', 'wcsaxes', 'HMpTy', 'ligo-gracedb']
    for e in c_exclude_list:
        try:
            install_requires.remove(e)
        except:
            pass

setup(name="marshallEngine",
      version=__version__,
      description="the engine behind the marshall webapp",
      long_description=readme(),
      long_description_content_type='text/markdown',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 2.7',
          'Topic :: Utilities',
      ],
      keywords=['astronomy, marshall, webapp'],
      url='https://github.com/thespacedoctor/marshallEngine',
      download_url='https://github.com/thespacedoctor/marshallEngine/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['marshallEngine=marshallEngine.cl_utils:main'],
      },
      zip_safe=False)

==> marshallEngine-1.0.3.tar.gz: marshallEngine-1.0.3/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/marshallEngine/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.md') as f:
        return f.read()

install_requires = [
    'pyyaml',
    'marshallEngine',
    'fundamentals',
    'astrocalc',
    'hmpty',
    'astropy',
    'matplotlib',
    'panstamps',
    'transientNamer',
    'tornado',
    'numpy'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    c_exclude_list = ['healpy', 'astropy',
                      'numpy', 'sherlock', 'wcsaxes', 'HMpTy', 'ligo-gracedb']
    for e in c_exclude_list:
        try:
            install_requires.remove(e)
        except:
            pass

setup(name="marshallEngine",
      version=__version__,
      description="the engine behind the marshall webapp",
      long_description=readme(),
      long_description_content_type='text/markdown',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 2.7',
          'Topic :: Utilities',
      ],
      keywords=['astronomy, marshall, webapp'],
      url='https://github.com/thespacedoctor/marshallEngine',
      download_url='https://github.com/thespacedoctor/marshallEngine/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['marshall=marshallEngine.cl_utils:main'],
      },
      zip_safe=False)
